auth0_flutter
library
Classes
ActorToken
Represents the acting party in a Custom Token Exchange delegation or
impersonation flow (RFC 8693 actor_token / actor_token_type).
ApiCredentials
User's credentials obtained from Auth0 for a specific API (audience) as the
result of exchanging the stored refresh token using a Multi-Resource Refresh
Token (MRRT).
Auth0
Primary interface for interacting with Auth0 using web authentication,
or the authentication API.
AuthenticationApi
An interface for calling some of the endpoints in
Auth0's Authentication API .
AuthenticationMethod
Credentials
A collection of authentication artifacts obtained from Auth0 when a user
logs in.
CredentialsManager
Abstract CredentialsManager that can be used to provide a custom
CredentialManager.
CustomTabsOptions
Configuration for using Chrome Custom Tabs on Android.
DatabaseUser
DefaultCredentialsManager
Default CredentialsManager implementation that passes calls to
the Native CredentialManagers provided by Auth0.Android or Auth0.Swift,
depending on the platform.
EnrollmentChallenge
Factor
IdTokenValidationConfig
Configuration settings for ID token validation.
LocalAuthentication
Settings for local authentication prompts.
MfaApi
An interface for completing Multi-Factor Authentication (MFA) flows using
an mfa_token, as part of Auth0's
flexible/expanded grant support .
MfaAuthenticator
An MFA authenticator enrolled by the user, as returned by
MfaApi.getAuthenticators.
MfaChallenge
The result of initiating an MFA challenge via MfaApi.challenge.
MfaEnrollmentChallenge
The result of initiating an MFA enrollment via one of the MfaApi.enroll*
methods.
MfaFactor
A single MFA factor referenced in an mfa_required error's requirements,
e.g. otp, phone, email, push-notification, recovery-code.
MfaRequirements
The factors a user can use or enroll, parsed from the mfa_requirements
field of an mfa_required error.
MyAccountApi
An interface for interacting with the
Auth0 My Account API .
MyAccountPasskeyAuthenticationMethod
An enrolled passkey authentication method returned by the My Account API.
PasskeyAuthenticatorResponse
The authenticator's response within a PasskeyCredential .
PasskeyChallenge
A challenge issued by Auth0 to begin a passkey ceremony.
PasskeyCredential
A passkey credential obtained from the platform authenticator.
PasskeyEnrollmentChallenge
A challenge issued by the My Account API to begin a passkey enrollment
ceremony.
Passwordless
Interface for the embedded (non-redirect) Passwordless OTP on database
connections flow.
PasswordlessChallenge
A challenge issued by Auth0 when starting a passwordless OTP flow against a
database connection.
SafariViewController
Configuration for using SFSafariViewController on iOS.
SSOCredentials
Authentication artifacts used to establish a web session from a native
application context (Native to Web SSO).
UserActor
Represents the act (actor) claim from an ID token issued during a Custom
Token Exchange delegation or impersonation flow.
UserProfile
A collection of properties that represents the authenticated user, extracted
from ID token claims.
WebAuthentication
An interface for authenticating users using the Auth0 Universal Login page .
WindowsWebAuthentication
A class for authenticating users using the Auth0 Universal Login page .