ChallengeType enum
How the user will get the multi-factor authentication challenge and prove possession.
Values
- otp → const ChallengeType
-
One-time password (OTP).
const ChallengeType(_otp) - oob → const ChallengeType
-
SMS/voice messages or out-of-band (OOB).
const ChallengeType(_oob)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
String value for the current enum case.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ChallengeType> - A constant List of the values in this enum, in order of their declaration.