Credentials class

A collection of authentication artifacts obtained from Auth0 when a user logs in.

Constructors

Credentials({required String idToken, required String accessToken, String? refreshToken, required DateTime expiresAt, Set<String> scopes = const {}, required UserProfile user, required String tokenType, DateTime? sessionExpiry})
Credentials.fromMap(Map result)
factory

Properties

accessToken → String
Token that can be used to make authenticated requests to the specified API (the audience value used on login).
final
expiresAt → DateTime
The absolute date and time of when the access token expires.
final
hashCode → int
The hash code for this object.
no setterinherited
idToken → String
A JSON web token that contains the user information.
final
refreshToken → String?
Token that can be used to request a new access token.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopes → Set<String>
The scopes that have been granted by Auth0.
final
sessionExpiry → DateTime?
The absolute date and time at which the upstream Identity Provider (IdP) session expires, when the connection has "Use ID Token for Session Expiry" enabled (id_token_session_expiry_supported: true).
final
tokenType → String
final
user → UserProfile
Properties and attributes relating to the authenticated user.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited