CredentialsManager class abstract

Abstract CredentialsManager that can be used to provide a custom CredentialManager.

Implementers

Constructors

CredentialsManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearApiCredentials({required String audience, String? scope}) Future<void>
Removes the stored API credentials for the given audience and scope.
clearCredentials() Future<bool>
credentials({int minTtl = 0, Set<String> scopes = const {}, Map<String, String> parameters = const {}}) Future<Credentials>
getApiCredentials({required String audience, Set<String> scope = const {}, int minTtl = 0, Map<String, String> parameters = const {}, Map<String, String> headers = const {}}) Future<ApiCredentials>
Exchanges the stored refresh token for ApiCredentials scoped to a specific API (audience), using a Multi-Resource Refresh Token (MRRT).
hasValidCredentials({int minTtl = 0}) Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
renewCredentials({Map<String, String> parameters = const {}}) Future<Credentials>
ssoCredentials({Map<String, String> parameters = const {}, Map<String, String> headers = const {}}) Future<SSOCredentials>
Exchanges the stored refresh token for a SSOCredentials that can be used to establish an authenticated web session from the current native session (Native to Web SSO).
storeCredentials(Credentials credentials) Future<bool>
toString() String
A string representation of this object.
inherited
user() Future<UserProfile?>

Operators

operator ==(Object other) bool
The equality operator.
inherited