isSessionExpired property

bool get isSessionExpired

Whether the upstream IdP session ceiling (IPSIE session_expiry) was reached. When true, the stored credentials can no longer be renewed and the user must re-authenticate. Distinct from isNoCredentialsFound.

Implementation

bool get isSessionExpired =>
    code == 'SESSION_EXPIRED' ||
    code ==
        '''
The session has reached the session_expiry ceiling set by the identity provider and is no longer valid. The user must re-authenticate.''';