PasswordlessType enum

Types of passwordless authentication.

Inheritance
Available extensions

Values

code → const PasswordlessType

Simple OTP code sent by email or SMS.

const PasswordlessType('code')

Regular Web HTTP link (web only, uses a redirect).

const PasswordlessType('link')
linkAndroid → const PasswordlessType

Android App Link.

const PasswordlessType('link_android')
linkIOS → const PasswordlessType

iOS Universal Link.

const PasswordlessType('link_ios')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<PasswordlessType>
A constant List of the values in this enum, in order of their declaration.