auth0_flutter_web
library
Classes
-
ActorToken
-
Represents the acting party in a Custom Token Exchange delegation or
impersonation flow (RFC 8693
actor_token / actor_token_type).
-
ApiCredentials
-
User's credentials obtained from Auth0 for a specific API (audience) as the
result of exchanging the stored refresh token using a Multi-Resource Refresh
Token (MRRT).
-
Auth0Web
-
Primary interface for interacting with Auth0 on web platforms.
-
MfaAuthenticator
-
An MFA authenticator enrolled by the user, as returned by
MfaApi.getAuthenticators.
-
MfaChallenge
-
The result of initiating an MFA challenge via
MfaApi.challenge.
-
MfaEnrollmentChallenge
-
The result of initiating an MFA enrollment via one of the
MfaApi.enroll*
methods.
-
MfaWeb
-
An interface for completing Multi-Factor Authentication (MFA) flows on the
web using an
mfa_token, as part of Auth0's
flexible/expanded grant support.
-
UserActor
-
Represents the
act (actor) claim from an ID token issued during a Custom
Token Exchange delegation or impersonation flow.
-
UserProfile
-
A collection of properties that represents the authenticated user, extracted
from ID token claims.
Enums
-
CacheLocation
-
The location where cached data is stored by the underlying SDK
on the web platform.
-
PhoneType
-
Exceptions / Errors
-
WebException
-
Exception thrown by
Auth0FlutterWebPlatform when something
goes wrong.