CacheLocation enum

The location where cached data is stored by the underlying SDK on the web platform.

Inheritance
Available extensions

Values

memory → const CacheLocation

Data is persisted in memory. The cache is lost on page reload.

localStorage → const CacheLocation

Data is persisted in the browser's local storage.

Note: There are security considerations when using this type of cache storage. Please see the Auth0 docs to learn more.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<CacheLocation>
A constant List of the values in this enum, in order of their declaration.