challenge method

Future<MfaChallenge> challenge({
  1. required String authenticatorId,
})

Initiates a challenge for the authenticator identified by authenticatorId (obtained from getAuthenticators).

For out-of-band factors (SMS, Email, Push) this triggers delivery of the code and returns an MfaChallenge whose oobCode you pass to verifyOob. For TOTP, verify directly with verifyOtp.

Implementation

Future<MfaChallenge> challenge({required final String authenticatorId}) =>
    Auth0FlutterWebPlatform.instance
        .mfaChallenge(_mfaToken, authenticatorId);