CustomTabsOptions class
Configuration for using Chrome Custom Tabs on Android.
Supports Partial Custom Tabs (bottom sheet / side sheet) on Chrome 107+. On older browsers, these options are ignored and the tab opens full-screen.
Constructors
Properties
-
allowedBrowsers
→ List<
String> -
An allowlist of browser packages to use for Custom Tabs.
final
- backgroundInteractionEnabled → bool?
-
Whether the user can interact with the app behind the partial tab.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialHeight → int?
-
The initial height of the bottom sheet in dp.
final
- initialWidth → int?
-
The initial width of the side sheet in dp.
final
- resizable → bool?
-
Whether the user can drag to resize the bottom sheet.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sideSheetBreakpoint → int?
-
The dp breakpoint to toggle between bottom sheet and side sheet.
final
- toolbarCornerRadius → int?
-
The toolbar's top corner radius in dp.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited