DefaultCredentialsManager class
Default CredentialsManager implementation that passes calls to the Native CredentialManagers provided by Auth0.Android or Auth0.Swift, depending on the platform.
- Inheritance
-
- Object
- CredentialsManager
- DefaultCredentialsManager
Constructors
- DefaultCredentialsManager(Account _account, UserAgent _userAgent, {LocalAuthentication? localAuthentication, CredentialsManagerConfiguration? credentialsManagerConfiguration, bool useDPoP = false})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearCredentials(
) → Future< bool> -
Removes the credentials from the storage if present.
override
-
credentials(
{int minTtl = 0, Set< String> scopes = const {}, Map<String, String> parameters = const {}}) → Future<Credentials> -
Retrieves the credentials from the storage and refreshes them if they have
already expired.
override
-
hasValidCredentials(
{int minTtl = 0}) → Future< bool> -
Checks if there is a valid
accessTokenavailable. If anaccessTokenis present, verifies whether it has expired or will expire within the givenminTtl. On Android devices, if the token has expired and a refresh token is present, this returns true if the token can be renewed using the refresh token.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
renewCredentials(
{Map< String, String> parameters = const {}}) → Future<Credentials> -
Fetches new set of credentials each time and stores them in storage.
This will replace the existing credentials currently stored
even if they are not expired.
override
-
ssoCredentials(
{Map< String, String> parameters = const {}, Map<String, String> headers = const {}}) → Future<SSOCredentials> -
Exchanges the stored refresh token for a SSOCredentials
that can be used to establish an authenticated web session from the
current native session (Native to Web SSO).
override
-
storeCredentials(
Credentials credentials) → Future< bool> -
Stores the given credentials in the storage. Must have an
access_tokenorid_tokenand aexpires_invalue.override -
toString(
) → String -
A string representation of this object.
inherited
-
user(
) → Future< UserProfile?> -
Fetches the user profile associated with the stored credentials.
Returns null if no credentials are present in storage.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited