MfaException class
An error raised by an MFA operation (getAuthenticators, enroll*,
challenge, verify).
- Implemented types
Constructors
-
MfaException(String code, String message, Map<
String, dynamic> details, Map _errorFlags, int statusCode) -
const
- MfaException.fromPlatformException(PlatformException e)
-
factory
- MfaException.unknown(String message)
-
const
Properties
- code → String
-
finalinherited
-
details
→ Map<
String, dynamic> -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isInvalidCode → bool
-
Whether the one-time / out-of-band code provided to
verifywas invalid.no setter - isInvalidRequest → bool
-
Whether the request was malformed, e.g. an invalid challenge type or a
verification with an authenticator not allowed by the
mfa_token.no setter - isMfaTokenExpired → bool
-
Whether the
mfa_tokenhas expired (default expiry is 10 minutes). The user must restart the original authentication request to obtain a new token.no setter - isNetworkError → bool
-
no setter
- isRetryable → bool
-
no setter
- message → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited