auth0_flutter_web library

Classes

ApiCredentials
User's credentials obtained from Auth0 for a specific API (audience) as the result of exchanging the stored refresh token using a Multi-Resource Refresh Token (MRRT).
Auth0Web
Primary interface for interacting with Auth0 on web platforms.

Enums

CacheLocation
The location where cached data is stored by the underlying SDK on the web platform.

Exceptions / Errors

WebException
Exception thrown by Auth0FlutterWebPlatform when something goes wrong.