getAuthenticators method
Lists the authenticators that can be used with the current mfa_token.
The results are filtered to the factors allowed by the mfa_token's
mfa_requirements.
Note: unlike the mobile API, auth0-spa-js does not accept a
client-side factorsAllowed filter, so that parameter is not exposed
here.
Implementation
Future<List<MfaAuthenticator>> getAuthenticators() =>
Auth0FlutterWebPlatform.instance.mfaGetAuthenticators(_mfaToken);